pub struct ImageView<'a> {
pub data: &'a [u8],
pub width: usize,
pub height: usize,
pub origin: [i32; 2],
}Expand description
Minimal grayscale view for refinement without taking a dependency on image.
Fields
data: &'a [u8]width: usizeheight: usizeorigin: [i32; 2]Origin of the view in the coordinate system of the response map / base image.
Implementations
Sourceimpl<'a> ImageView<'a>
impl<'a> ImageView<'a>
pub fn from_u8_slice( width: usize, height: usize, data: &'a [u8], ) -> Option<Self>
pub fn with_origin( width: usize, height: usize, data: &'a [u8], origin: [i32; 2], ) -> Option<Self>
pub fn supports_patch(&self, cx: i32, cy: i32, radius: i32) -> bool
pub fn sample(&self, gx: i32, gy: i32) -> f32